#simple bitfield object
from collections import OrderedDict

class Adafruit_bitfield(object):
    def __init__(self, _structure):
        self._structure = OrderedDict(_structure)
        
        for key, value in self._structure.iteritems():
            setattr(self, key, 0)
            
    def get(self):
        fullreg = 0
        pos = 0
        for key, value in self._structure.iteritems():
            fullreg = fullreg | ( (getattr(self, key) & (2**value - 1)) << pos )
            pos = pos + value
            
        return fullreg
    	
    def set(self, data):
    	pos = 0
    	for key, value in self._structure.iteritems():
    		setattr(self, key, (data >> pos) & (2**value - 1))
    		pos = pos + value


try:
    # Try using ez_setup to install setuptools if not already installed.
    from ez_setup import use_setuptools
    use_setuptools()
except ImportError:
    # Ignore import error and assume Python 3 which already has setuptools.
    pass

from setuptools import setup, find_packages

classifiers = ['Development Status :: 4 - Beta',
               'Operating System :: POSIX :: Linux',
               'License :: OSI Approved :: MIT License',
               'Intended Audience :: Developers',
               'Programming Language :: Python :: 2.7',
               'Programming Language :: Python :: 3',
               'Topic :: Software Development',
               'Topic :: System :: Hardware']

setup(name              = 'Adafruit-bitfield',
      version           = '1.5',
      author            = 'Dean Miller',
      author_email      = 'dean@adafruit.com',
      description       = 'Simple bitfield helper library.',
      license           = 'MIT',
      classifiers       = classifiers,
      url               = 'https://github.com/adafruit/Adafruit_bitfield_python/',
      dependency_links  = [],
      install_requires  = [],
      packages          = find_packages())